@@ -15,10 +15,8 @@
 # limitations under the License.
 
 for lib in \
-        python-novaclient \
         python-keystoneclient \
         python-ironicclient \
-        python-designateclient \
         os-client-config \
         keystoneauth
 do
